==> qy-1.0.0.tar.gz: qy-1.0.0/seed/qy.sh.sh <==
#include <emsg: see ... '~$ sh aaa.sh.c -h'   (other opt:no/-m/-w/)>	/*
C='^[#]SH_'			;O=${0##*[/]};R=`dirname $0`/;R0=$R$O;Re=eval\ ;R=$R${O%%.*}
O=${0##*.};Rs=$R.$O;Rm=$R.tmp.$O;Rh=$R.h;R=$Rs$Rh$Rm;Rp='printf %s\n ';Rc=:;O="
";[ "${R##*$R0*}" = '' ]&&$Rp"$0:NGext"&&exit 1;R='sed -ne ';Cm=$R'"/[E]ND/!d;:l
n;p;b l"<$R0>$Rm;$Rp"$Rm"';Rw=$R'"/$C$R/!d;:l;n;/${C}ED/q;p;b l"<$R0';Cw="(R=LS
$Rw;$Rw>&3;R=HD;$Rw;R=SC;$Rw>&3)"'>$Rh 3>$Rs;$Rp"$Rh $Rs"';RB=$($R"s/${C}OP//p"\
<$R0|(F=mw;while read -r a b;do B=${a%:};F=`$Rp"$F"|$R"s#$B:*##;p"`${a%_};$Rp"
C$B=\$(cat<<'E'$O$b${O}E$O)";done;$Rp"R1=$F"));$Re"$RB";while getopts $R1 R;do
case $R in \?)exit 1;;*)$Re"O$R=\$OPTARG";Rc=$Rc$O`$Re'$Rp"$C'$R\"`;;esac;done
[ "$Rc" = : ]&&Rc=$Cm;shift $((OPTIND-1));$Re"$C_$O$Rc";exit #END  GPLv3+*/

#SH_LS
#!/bin/sh
# AGPLv3+
:<< 'EEE'
/* Copyright (C) 2022 Momi-g

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
 published by the Free Software Foundation, either version 3 of the
 License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.
 
 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/
EEE

:<< 'EEE'
#SH_doc
title=*SH_bn* section=1 repnl=\040
@name *SH_bn*
@_brief alt-python same as alt-js
@_syno
	qy [infile/stdin] [-o outfile]
	qy [-hHVs]
@tl_dr
	@(code)@
 --- src.qy
 fn f(){
 if(1==1){print(10)}
 }
 
 ~$ qy src.qy	#..or: cat src.qy | qy
 #>> def f():pass
 		if 1==1:pass
 			print(10)
 		pass
 	pass

 --- support-syntax info
 ~$ qy -s | qy
 #>> output sample code
	@()
@_opt
		@(list_o)
	-hHV: usage, version
	-s: output sample code
	-o file: output dist (dfl@:stdout)
		@()
@_desc
	*SH_bn* is transpiler(==text conv) for c-lang style programmer. --
	you can write python code with c-syntax.
		@(code)--@
	- for(){}, if(){} >>> indent code
	- &&, || >>> 'and' 'or' etc
	- /*...*/  >>> """..."""
	- and other word/syntax conv
	- ignore(fall-through) other syntax == allow mix python raw code
		@()--@
	currently supports only a few syntax.
	you can add your own rule with editing *SH_bn*(posix-sh) directly.
		@(code)--
	(add 'try-except' blockcode)
	~$ your_editor $(which qy)
	_EL <- "else" / "el"	>>> _EL <- "else"/"el"	/"try"/"except"
		@()--
	see 'ped -h' help about peg-grammer.
@exit_status suc/fail == 0/not0
@notes -
@compat c compiler(posix-2001+), posix-shell
@copyright	Copyright (C) 2022 Momi-g, AGPLv3+
@_ver 2022-09-27 v1.0.0 (2022-09-27 v1.0.0)
@_see -
#SH_docE
EEE
#SH_ED

#SH_HD
#SH_ED

#SH_SC
f_err(){
	echo "*SH_bn*: err. $*" >/dev/stderr
	exit 1
}

f_usage(){
cat << 'EEE'
HowTo (*SH_bn*, alt-python, conv c-style code to python)
opt: -hH(elp), -V(er), -s(ample), -o(utput file)
------
  ~$ qy -s	#>> output sample code
  ~$ qy -s| qy #>> conv code
  
  ~$ src.qy | qy > src.py
  ~$ qy src.qy -o src.py	#same as above
 
 (src.qy code sample)
 fn f(){                        def f():
 if(1==1){print(10)}	>>>    	  if 1==1:pass
 }                                  print(10)
                                  pass
                                pass
 ... edit *SH_bn* directly if you needs your own syntax / output format. 
EEE
exit 0
}

f_usageH(){
	cat <<- 'E E'|sed -e'1d;$d'
	#SH_rf* *SH_bn*.1.txt
	E E
	exit 0
}

f_verinfo(){
		cat <<- 'EEE'
	*SH_bn* *SH_ver* *SH_copy* 
		EEE
	exit 0
}

f_sample(){
	cat << 'EEE'	#|sed -e'1d;$d'
tl_dr: ~$ qy -s | qy
###### blk
/*"
fn f(){
	print("dunc")
	fn ff(){
		print("gw")
	}
}
*/

fn f(){
	print("dunc")
	fn ff(){
		print("gw")
	}
}

######
/*"
fn f(){print("dunc")
	fn ff(){ print("gw") }}
*/

fn f(){print("dunc")
	fn ff(){ print("gw") }}

######
/*"
class cl(){
			fn __init(self){print("hw")
	}
	x = 10}
*/

class cl(){
			fn __init(self){print("hw")
	}
	x = 10}

###### lit/cmt
"""
//hw
/* hw */
/*" mulit"x3 lits"*/
/*' mulit"'''" lits''*/
'''an
y'''
"""

//hw
/* hw */
/*" mulit""" lits "*/
/*' mulit"'''" lits ''*/
'''an
y'''

###### token
/*" ++ -- != ! && || := nil NuLL nOne true FALSE */
++ -- != ! && || := nil NuLL nOne true FALSE

###### import/evil(==eval)
/*"
m = use(aa.bb.cc)
use(aa.bb.cc)
use(aa.bb.*)
if(0){evil("print('hw')")}
"*/

m = use(aa.bb.cc)
use(aa.bb.cc)
use(aa.bb.*)
if(0){evil("print('hw')")}
EEE
	exit 0
}

qyped=$(cat<<'EEE'|sed -e'1d;$d'
	#SH_rf* *SH_bn*.ped
EEE
)

f_qypst(){
 awk ' BEGIN{s=""}
 $0 ~ /^\^\^/ { s=substr(s, 2);$0="pass"}
 $0~/^\^/{ $0=s substr($0,2); s=s "\t"; print; next }
 {print(s $0)}'
}

*SH_bn*()(
	s0="$0"
	d0="${s0%/*}"
	cmd='cat -- "$ifile" | $d0/ped -re "$qyped" | f_qypst > "$ofile" '
	#echo "#stderr_msg: $cmd" >/dev/stderr
	eval "$cmd"
	#echo "#stderr_msg: $cmd" >/dev/stderr
)

*SH_bn*_main()(
		:<<- 'CMT'
	while getopts ":hHVQ" c; do case "$c" in				
	[?:]) f_err "bad opt: $OPTARG, $*" ;;	
	h) f_usage	;;
	H) f_usage_H	;;
	V) f_version_info	;;
	Q) printf '%s\n' "$code"; exit 0	;;
	s) f_eg1	;;
	S) f_eg2	;;
	esac; done; shift $(($OPTIND-1))
		CMT
	
	ass=""
	ofile="/dev/stdout"
	ifile="/dev/stdin"
	for ag in "$@"; do
		[ "$ass" = 0 ] && { ifile="$ag"; break;}
		[ -z "$ass" ] || { eval "$ass"; ass=""; continue;}
		[ "${ag#-h}" != "$ag" ] && f_usage
		[ "${ag#-H}" != "$ag" ] && f_usageH
		[ "${ag#-V}" != "$ag" ] && f_verinfo
		[ "${ag#-s}" != "$ag" ] && f_sample
		[ "${ag#-o}" != "$ag" ] && {
			ass='ofile="$ag"'
			ag="${ag#..}"
			[ -z "$ag" ] || { eval "$ass"; ass=""; continue;}
		}
		[ "${ag}" = "--" ] && ass=0 && continue
		ifile="$ag"
		[ "${ag}" = "-" ] && continue
		[ "${ag#-}" != "$ag" ] && f_err "bad opt: $ag"
	done
	[ "$ifile" = "-" ] && ifile="/dev/stdin"
	[ -w "$ifile" ] || f_err "bad file: $ifile"

		# exec
	*SH_bn* "$@"
)
*SH_bn*_main "$@" || exit	#SH_MAIN

#SH_TSS
test_cmd(){
	cmd="*SH_bn*"
	buf=`./$cmd -h`;	_suc 1
	buf=`./$cmd -H`;	_suc 2
	buf=`./$cmd -V`;	_suc 3
	buf=`./$cmd -s`;	_suc 4
	echo "ok: test_cmd"
}
#SH_TSE

#SH_TSS_
test_22(){
	:
	_eq 1 1
}
#SH_TSE

#SH_SMP
#SH_SMPE

:<<'EEE'
 change log
 --
2022-09-27  Momi-g	<dmy@dmy.dmy>

	* qy.sh.c : init v1.0.0

EEE

#SH_ED


#SH_OP _ a=`sed -ne "/${C}DF/!d;:l;n;/${C}DE/q;p;bl"<$R0`;eval "$a";set +e	#*/
#SH_OP h $p"-tsbS:test/eg/.o/.so -LMP:leak,mem,prof -f:funcs -o:bldout	GPLv3+"	 #*/
#SH_OP f sed -ne "/${C}DF/q;/;/d;/^[a-z].*)/p"<$R0|tr -d ' \t'|grep -F '()' #*/
#SH_OP t $e"$CW";ftt "$@";bash --posix $Ox $tf
#SH_OP s fgr0 "${C}SMP" "${C}SMPE"<$R0>eg.sh #;$p"luajit eg.lua"|fv
#SH_OP x Ox="-x"

#SH_OP b $e"$CW"
#SH_OP W $e"$Cm$O$Cw">/dev/null;fborn;chmod 755 $bn;$e"$Cs";$p"$bn $Rs $Rh $tf"	#*/
#SH_OP o $e"$CW";$p'fman $Rh 1'|fv		#*/

#SH_DF
#-- noob
fman()( $p"fgr0 '${C}doc' '${C}docE'<$1|amn >$bn.$2
 mandoc -Thtml <$bn.$2 >$bn.$2.html
 man -Tutf8 -l -<$bn.$2|sed -e 's/.`printf \"\\b\"`//g'>$bn.$2.txt
 "|fv
 #(echo '.mso ja.tmac';cat $bn.$2)|man -Tutf8 -l -|sed -e 's/.`printf \"\\b\"`//g'>$bn.$2.txt"|fv
)

#-- vars
bn=`basename ${Rs%.*}`; tf=${Rs%/*}/${bn}.ts.${Rs##*.}; e="eval "; p="$Rp"
#-- mod
fv()(while read -r a;do $e"cat<<E$O# $a${O}E"|sed -e 's@-L.*-L[^ ]*@-L(omit)@g'>/dev/stderr;$e"$a";done)

fbn()(sed -e "s@\*${C##*]}bn\*@$bn@g"|frv|fry|flit|frf)
fsn()(tr -s ' \t' '\n')
fsl()(tr -s '\n' ' ')
fu()(fsn|sort -u)
fU()(fu|fsl;$p)

fgr()(sed -e "/$1/!d;:l;/$2/{p;d};n;bl")	#切出
fgr0()(sed -ne "/$1/!d;:l;n;/$2/d;p;bl")	#抜き切出
fgR()(sed -ne "/$1/bl;p;d;:l;n;/$2/d;bl")	#切すて
fg()(sed -ne "s/.*${C##*]}co\*\([^*]*\).*$/\1/p" "$@"|fsn|awk '!a[$0]{a[$0]=1;print}'|fsl)

#-- longcmd
frf()(
 # *sh_rf* 0 a.txt b.txt ...でcat纏めて出力 top0でsrcinfoは無し出力
 awk -v tg="${C##*]}rf" -v cs='#' -v ce='' 'index($0,tg){
 s=substr($0, index($0,tg)+length(tg)+1);split(s, a)
 m="[ -f \"%s\" ]&&(echo \"%s--copyfrom %s %s\";cat \"%s\";echo \"%s--copyend %s %s\")"
 mm="[ -f \"%s\" ]&&(_=\"%s%s%s\";cat \"%s\";_=\"%s%s%s\")"
 for(i=1;i in a;i++){v=a[i];if(v==0){m=mm;continue};system(sprintf(m,v,cs,v,ce,v,cs,v,ce))}
 next
 }
 {print}'
)
frv()(buf=`awk '$1=="@_ver" {print $3;exit}'<$R0`;sed -e "s@\*${C##*]}ver\*@$buf@g")
fry()(buf=`awk '$1~ /^@license|^@copy/ {$1="";print;exit}'<$R0`;sed -e "s@\*${C##*]}copy\*@$buf@g")
flit()(sed -ne "/${C}lit/bl;p;d;:l;n;/${C}litE/d;"'s/[\]/&&/g;s/"/\\"/g;s@.*@"&\\n"@g;p;bl')

fte()(
 cat > $Rm-
 suite=$(cat $Rm-|awk '$1~/^test_[^(]*\(\)/{print $1}'|sed -e 's/[(].*//g')
 [ $# = 0 ] && suite="$suite $suite"|| suite="$suite $@"
 suite=`$p'%s\n' "$suite"|tr '[ \t]' '\n'|sort|uniq -d|fsl`
 (cat $bn $Rm-|grep -vF "${C##*]}MAIN"
 $p' [ $# = 0 ] && set -- '"$suite"';for fc;do $fc ;done;_res')
 rm -f $Rm-
)
ftt()(shunit_m>$Rm;fte "$@"<$tf>>$Rm;mv $Rm $tf)

fborn(){
 fgr0 "${C}TSS" "${C}TSE"<$R0|fbn>$tf
 fgR "${C}TSS" "${C}TSE"<$Rs|fbn|tee $Rm>$bn;mv -f $Rm $Rs;fbn<$Rh>$Rm;mv $Rm $Rh
 fgR "${C}TSS_" "${C}TSE"<$R0 |fgr0 "${C}TSS" "${C}TSE"|fbn|fte>tests.code
}
#SH_DE

==> qy-1.0.1.tar.gz: qy-1.0.1/seed/qy.sh.sh <==
#include <emsg: see ... '~$ sh aaa.sh.c -h'   (other opt:no/-m/-w/)>	/*
C='^[#]SH_'			;O=${0##*[/]};R=`dirname $0`/;R0=$R$O;Re=eval\ ;R=$R${O%%.*}
O=${0##*.};Rs=$R.$O;Rm=$R.tmp.$O;Rh=$R.h;R=$Rs$Rh$Rm;Rp='printf %s\n ';Rc=:;O="
";[ "${R##*$R0*}" = '' ]&&$Rp"$0:NGext"&&exit 1;R='sed -ne ';Cm=$R'"/[E]ND/!d;:l
n;p;b l"<$R0>$Rm;$Rp"$Rm"';Rw=$R'"/$C$R/!d;:l;n;/${C}ED/q;p;b l"<$R0';Cw="(R=LS
$Rw;$Rw>&3;R=HD;$Rw;R=SC;$Rw>&3)"'>$Rh 3>$Rs;$Rp"$Rh $Rs"';RB=$($R"s/${C}OP//p"\
<$R0|(F=mw;while read -r a b;do B=${a%:};F=`$Rp"$F"|$R"s#$B:*##;p"`${a%_};$Rp"
C$B=\$(cat<<'E'$O$b${O}E$O)";done;$Rp"R1=$F"));$Re"$RB";while getopts $R1 R;do
case $R in \?)exit 1;;*)$Re"O$R=\$OPTARG";Rc=$Rc$O`$Re'$Rp"$C'$R\"`;;esac;done
[ "$Rc" = : ]&&Rc=$Cm;shift $((OPTIND-1));$Re"$C_$O$Rc";exit #END  GPLv3+*/

#SH_LS
#!/bin/sh
# AGPLv3+
:<< 'EEE'
/* Copyright (C) 2022 Momi-g

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
 published by the Free Software Foundation, either version 3 of the
 License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.
 
 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/
EEE

:<< 'EEE'
#SH_doc
title=*SH_bn* section=1 repnl=\040
@name *SH_bn*
@_brief alt-python same as alt-js
@_syno
	qy [infile/stdin] [-o outfile]
	qy [-hHVs]
@tl_dr
	@(code)@
 --- src.qy
 fn f(){
 if(1==1){print(10)}
 }
 
 ~$ qy src.qy	#..or: cat src.qy | qy
 #>> def f():
 		pass
 		if 1==1:
 			print(10)
 		pass
 	pass

 --- support-syntax info
 ~$ qy -s | qy
 #>> output sample code
	@()
@_opt
		@(list_o)
	-hHV: usage, version
	-s: output sample code
	-o file: output dist (dfl@:stdout)
		@()
@_desc
	*SH_bn* is transpiler(==text conv) for c-lang style programmer. --
	you can write python code with c-syntax.
		@(code)--@
	- for(){}, if(){} >>> indent code
	- &&, || >>> 'and' 'or' etc
	- /*...*/  >>> """..."""
	- and other word/syntax conv
	- ignore(fall-through) other syntax == allow mix python raw code
		@()--@
	currently supports only a few syntax.
	you can add your own rule with editing *SH_bn*(posix-sh) directly.
		@(code)--
	(add 'try-except' blockcode)
	~$ your_editor $(which qy)
	_EL_W <- "else" / "el"	>>>  "else"/"el"/"try"/"except"
		@()--
	see 'ped -h' help about peg-grammer.
@exit_status suc/fail == 0/not0
@notes	Python's grammar is inconsistent, and the API is changed with
 an idea, without any glance. I created 'qy' to save the conscience of
 those who need to handle Python.

@compat c compiler(posix-2001+), posix-shell
@copyright	Copyright (C) 2022 Momi-g, AGPLv3+
@_ver 2022-09-28 v1.0.1 (2022-09-27 v1.0.0)
@_see -
#SH_docE
EEE
#SH_ED

#SH_HD
#SH_ED

#SH_SC
f_err(){
	echo "*SH_bn*: err. $*" >/dev/stderr
	exit 1
}

f_usage(){
cat << 'EEE'
HowTo (*SH_bn*, alt-python, conv c-style code to python)
opt: -hH(elp), -V(er), -s(ample), -o(utput file)
------
  ~$ qy -s	#>> output sample code
  ~$ qy -s| qy #>> conv code
  
  ~$ src.qy | qy > src.py
  ~$ qy src.qy -o src.py	#same as above
 
 (src.qy code sample)
 fn f(){                        def f():
 if(1==1){print(10)}	>>>    	  if 1==1:
 }                                  print(10)
                                  pass
                                pass
 ... edit *SH_bn* directly if you needs your own syntax / output format. 
EEE
exit 0
}

f_usageH(){
	cat <<- 'E E'|sed -e'1d;$d'
	#SH_rf* *SH_bn*.1.txt
	E E
	exit 0
}

f_verinfo(){
		cat <<- 'EEE'
	*SH_bn* *SH_ver* *SH_copy* 
		EEE
	exit 0
}

f_sample(){
	cat << 'EEE'	#|sed -e'1d;$d'
# tl_dr:
# ~$ qy -s 	#ck qy_code
# ~$ qy -s | qy > a.py	#conv to python
# ~$ python3 ./a.py		#exec test

###### sample code
	#-- /*" mycode.qy */
/*" mycode.qy */

	#-- //lcmt
//lcmt


	#-- use(sys)
use(sys)

	#-- use(math.sqrt)
use(math.sqrt)
print( sqrt(121) )

	#-- use(os.*)
use(os.*)
print(getpid() )

	#-- av=use(sys.argv)
av = use(sys.argv)
print(av[0])

	#-- /*' hw */
s = /*' hw */

	#-- fn hw(n=1){ print(s, n) }
fn hw(n=1){ print(s, n) }

"""
class cl(){
	fn __i(self){ self.num = 10 }
	num=0
	def f(self){
		self.num++
		if(self.num>0 && 1 ){ print("self_num:", self.num) }
	}
	fn ff(){ print("from cl") }
}
"""
class cl(){
	fn __i(self){ self.num = 10 }
	num=0
	def f(self){
		self.num++
		if(self.num>0 && 1 ){ print("self_num:", self.num) }
	}
	fn ff(){ print("from cl") }
}

	#-- for(i in range(10)){ hw(i) }
for(i in range(10)){ hw(i) }

cl.ff()
obj = cl()
obj.f()


###### blk

#-- fn f(){print("") fn ff(){print("gw") }}
fn f(){print("") fn ff(){print("gw") }}

#-- fn ff(){}, fn/class/def
fn f(){}
class cl(){}
def f(){}

#-- for(){}, for(x){...} >> for x: ...
for(i in range(3)){}

#-- if(){},if/else if/elseif/elif/ef	
#-- else{}, else/el
if(0){}

ef(0){}
el{}

###### lit/cmt
	#-- //hw
//hw

	#-- /* hw */
/* hw */

	#-- /*" mulit"x3 lits"*/
/*" mulit""" lits"*/

		#--/*' mulit"'''" lits''*/
/*' mulit"'''" lits''*/

	#-- '''any'''
'''any'''

###### token
# ++ -- != ! && || := nil NuLL nOne true FALSE __i
#>> += 1 -= 1 !=  not   and   or  = None None None True False  __init__

###### import/eval/for(dic)/ismain
if(0){
	#-- m = use(aa.bb.cc)
m = use(aa.bb.cc)
	#-- use(aa.bb.cc)
use(aa.bb.cc)
	#-- use(aa.bb.*)
use(aa.bb.*)
}

	#-- eval_("xxx")
eval_("print('eval_() test')")
print(e, "suc==null, nx is ERRtest\n\n")

	#-- err: eval_("badcode")
eval_("errtest_str")
print(e)

	#-- for( k,v in pairs(d) ){}
d=locals()
for( k,v in pairs(d) ){ print("pairs() test",k,v);break }

	#-- ismain()
if(ismain()){ print("ismain() test") }

print("*SH_bn*, all ok")
EEE
	exit 0
}

qyped=$(cat<<'EEE'|sed -e'1d;$d'
	#SH_rf* *SH_bn*.ped
EEE
)

f_qypst(){
#cat;return
 awk ' BEGIN{s=""}
 $0~ /^\^\^\^/ { $0=substr($0,4); s=substr(s, 2) }
 $0~ /^\^\^/ { $0=substr($0,3); s=substr(s, 2);if(NF==0){$0="pass"}}
 $0~ /^\^/{ $0=substr($0,2); s=s "\t"; if(NF==0){$0="pass"} }
 {print(s $0)}'
}

*SH_bn*()(
	s0="$0"
	d0="${s0%/*}"
	cmd='cat -- "$ifile" | $d0/ped -re "$qyped" | f_qypst > "$ofile" '
	#echo "#stderr_msg: $cmd" >/dev/stderr
	eval "$cmd"
	#echo "#stderr_msg: $cmd" >/dev/stderr
)

*SH_bn*_main()(
		:<<- 'CMT'
	while getopts ":hHVQ" c; do case "$c" in				
	[?:]) f_err "bad opt: $OPTARG, $*" ;;	
	h) f_usage	;;
	H) f_usage_H	;;
	V) f_version_info	;;
	Q) printf '%s\n' "$code"; exit 0	;;
	s) f_eg1	;;
	S) f_eg2	;;
	esac; done; shift $(($OPTIND-1))
		CMT
	
	ass=""
	ofile="/dev/stdout"
	ifile="/dev/stdin"
	for ag in "$@"; do
		[ "$ass" = 0 ] && { ifile="$ag"; break;}
		[ -z "$ass" ] || { eval "$ass"; ass=""; continue;}
		[ "${ag#-h}" != "$ag" ] && f_usage
		[ "${ag#-H}" != "$ag" ] && f_usageH
		[ "${ag#-V}" != "$ag" ] && f_verinfo
		[ "${ag#-s}" != "$ag" ] && f_sample
		[ "${ag#-o}" != "$ag" ] && {
			ass='ofile="$ag"'
			ag="${ag#..}"
			[ -z "$ag" ] || { eval "$ass"; ass=""; continue;}
		}
		[ "${ag}" = "--" ] && ass=0 && continue
		ifile="$ag"
		[ "${ag}" = "-" ] && continue
		[ "${ag#-}" != "$ag" ] && f_err "bad opt: $ag"
	done
	[ "$ifile" = "-" ] && ifile="/dev/stdin"
	[ -w "$ifile" ] || f_err "bad file: $ifile"

		# exec
	*SH_bn* "$@"
)
*SH_bn*_main "$@" || exit	#SH_MAIN

#SH_TSS
test_cmd(){
	cmd="*SH_bn*"
	buf=`./$cmd -h`;	_suc 1
	buf=`./$cmd -H`;	_suc 2
	buf=`./$cmd -V`;	_suc 3
	buf=`./$cmd -s`;	_suc 4
	which python3 && {
		python3 -c "$(./$cmd -s| ./$cmd )" >/dev/null
		_suc 5
	}
	echo "ok: *SH_bn*_test_cmd"
}
#SH_TSE

#SH_TSS_
test_22(){
	:
	_eq 1 1
}
#SH_TSE

#SH_SMP
#SH_SMPE

:<<'EEE'
 change log
 --
2022-09-28  Momi-g	<dmy@dmy.dmy>

	* qy.sh.c(qy.ped) : fix ':pass(nl)', '__i', 'for(x)' and other syntax

	* qy.sh.c(f_sample) : improve sample code

2022-09-27  Momi-g	<dmy@dmy.dmy>

	* qy.sh.c : init v1.0.0

EEE

#SH_ED


#SH_OP _ a=`sed -ne "/${C}DF/!d;:l;n;/${C}DE/q;p;bl"<$R0`;eval "$a";set +e	#*/
#SH_OP h $p"-tsbS:test/eg/.o/.so -LMP:leak,mem,prof -f:funcs -o:bldout	GPLv3+"	 #*/
#SH_OP f sed -ne "/${C}DF/q;/;/d;/^[a-z].*)/p"<$R0|tr -d ' \t'|grep -F '()' #*/
#SH_OP t $e"$CW";ftt "$@";bash --posix $Ox $tf
#SH_OP s fgr0 "${C}SMP" "${C}SMPE"<$R0>eg.sh #;$p"luajit eg.lua"|fv
#SH_OP x Ox="-x"

#SH_OP b $e"$CW"
#SH_OP W $e"$Cm$O$Cw">/dev/null;fborn;chmod 755 $bn;$e"$Cs";$p"$bn $Rs $Rh $tf"	#*/
#SH_OP o $e"$CW";$p'fman $Rh 1'|fv		#*/

#SH_DF
#-- noob
fman()( $p"fgr0 '${C}doc' '${C}docE'<$1|amn >$bn.$2
 mandoc -Thtml <$bn.$2 >$bn.$2.html
 man -Tutf8 -l -<$bn.$2|sed -e 's/.`printf \"\\b\"`//g'>$bn.$2.txt
 "|fv
 #(echo '.mso ja.tmac';cat $bn.$2)|man -Tutf8 -l -|sed -e 's/.`printf \"\\b\"`//g'>$bn.$2.txt"|fv
)

#-- vars
bn=`basename ${Rs%.*}`; tf=${Rs%/*}/${bn}.ts.${Rs##*.}; e="eval "; p="$Rp"
#-- mod
fv()(while read -r a;do $e"cat<<E$O# $a${O}E"|sed -e 's@-L.*-L[^ ]*@-L(omit)@g'>/dev/stderr;$e"$a";done)

fbn()(sed -e "s@\*${C##*]}bn\*@$bn@g"|frv|fry|flit|frf)
fsn()(tr -s ' \t' '\n')
fsl()(tr -s '\n' ' ')
fu()(fsn|sort -u)
fU()(fu|fsl;$p)

fgr()(sed -e "/$1/!d;:l;/$2/{p;d};n;bl")	#切出
fgr0()(sed -ne "/$1/!d;:l;n;/$2/d;p;bl")	#抜き切出
fgR()(sed -ne "/$1/bl;p;d;:l;n;/$2/d;bl")	#切すて
fg()(sed -ne "s/.*${C##*]}co\*\([^*]*\).*$/\1/p" "$@"|fsn|awk '!a[$0]{a[$0]=1;print}'|fsl)

#-- longcmd
frf()(
 # *sh_rf* 0 a.txt b.txt ...でcat纏めて出力 top0でsrcinfoは無し出力
 awk -v tg="${C##*]}rf" -v cs='#' -v ce='' 'index($0,tg){
 s=substr($0, index($0,tg)+length(tg)+1);split(s, a)
 m="[ -f \"%s\" ]&&(echo \"%s--copyfrom %s %s\";cat \"%s\";echo \"%s--copyend %s %s\")"
 mm="[ -f \"%s\" ]&&(_=\"%s%s%s\";cat \"%s\";_=\"%s%s%s\")"
 for(i=1;i in a;i++){v=a[i];if(v==0){m=mm;continue};system(sprintf(m,v,cs,v,ce,v,cs,v,ce))}
 next
 }
 {print}'
)
frv()(buf=`awk '$1=="@_ver" {print $3;exit}'<$R0`;sed -e "s@\*${C##*]}ver\*@$buf@g")
fry()(buf=`awk '$1~ /^@license|^@copy/ {$1="";print;exit}'<$R0`;sed -e "s@\*${C##*]}copy\*@$buf@g")
flit()(sed -ne "/${C}lit/bl;p;d;:l;n;/${C}litE/d;"'s/[\]/&&/g;s/"/\\"/g;s@.*@"&\\n"@g;p;bl')

fte()(
 cat > $Rm-
 suite=$(cat $Rm-|awk '$1~/^test_[^(]*\(\)/{print $1}'|sed -e 's/[(].*//g')
 [ $# = 0 ] && suite="$suite $suite"|| suite="$suite $@"
 suite=`$p'%s\n' "$suite"|tr '[ \t]' '\n'|sort|uniq -d|fsl`
 (cat $bn $Rm-|grep -vF "${C##*]}MAIN"
 $p' [ $# = 0 ] && set -- '"$suite"';for fc;do $fc ;done;_res')
 rm -f $Rm-
)
ftt()(shunit_m>$Rm;fte "$@"<$tf>>$Rm;mv $Rm $tf)

fborn(){
 fgr0 "${C}TSS" "${C}TSE"<$R0|fbn>$tf
 fgR "${C}TSS" "${C}TSE"<$Rs|fbn|tee $Rm>$bn;mv -f $Rm $Rs;fbn<$Rh>$Rm;mv $Rm $Rh
 fgR "${C}TSS_" "${C}TSE"<$R0 |fgr0 "${C}TSS" "${C}TSE"|fbn|fte>tests.code
}
#SH_DE
